@@ -30,6 +30,9 @@ where `bias` is a file.
 # Support argument parsing:
 import argparse
 
+# Support deprecation warnings:
+import warnings
+
 # Support static type checks:
 from typing import Optional, Union, List, Callable, Dict, Tuple
 
@@ -438,10 +441,11 @@ def _wham(**args):
      help="show command instead of executing it")
 @arg("--port", help="set port", default=0)
 @arg("--screen-cmd", help="screen command", default="screen")
+@arg("--screen-log", help="screen logfile (no logfile by default)", default="")
 @arg("--python-exec", help="python executable", default="")
-@arg("-S", "--sockname", help="screen sockname", default="jupyter-server")
+@arg("-S", "--sockname", help="screen sockname", default="(path):jupyter-server:(port)")
 @arg("--no-screen", help="do not run screen", action="store_true")
-@arg("--keep-ld-library-path", help="propagate LD_LIBRARY_PATH through screen", action="store_true")
+@arg("--keep-ld-library-path", help="(ignored, this is the default now)", action="store_true")
 @arg("--detach", help="detach screen", action="store_true")
 def _jrun(**kargs):
     """
@@ -460,6 +464,9 @@ def _jrun(**kargs):
        running.
     """
     from . import jremote
+    if kargs["keep_ld_library_path"]:
+        warnings.warn("--keep-ld-library-path is the default now - this flag might be removed in the future", FutureWarning)
+    kargs["keep_ld_library_path"]=True
     jremote.run_server(**kargs)
 
 @command("jremote", help="Run jupyter client",
@@ -563,14 +570,18 @@ def _notify(**kargs):
 @arg("--screen-cmd", help="screen command", default="screen")
 @arg("--screen-log", help="screen logfile (no logfile by default)", default="")
 @arg("--no-screen", help="do not run screen", action="store_true")
-@arg("--keep-ld-library-path", help="propagate LD_LIBRARY_PATH through screen", action="store_true")
-@arg("-S", "--sockname", help="screen sockname", default="cron")
+@arg("--keep-ld-library-path", help="(ignored, this is the default now)", action="store_true")
+@arg("-S", "--sockname", help="screen sockname", default="(path):cron")
 @arg("--python-exec", help="python executable", default="")
 @arg("--detach", help="detach screen", action="store_true")
+@arg("--unique", help="allow only one screen with this socket", action="store_true")
 @arg("--period", help="period (seconds)", default=3600, type=int)
 @arg("--max-times", help="maximum number of calls", default=None, type=int)
 def _cron(**kargs):
     from . import cron
+    if kargs["keep_ld_library_path"]:
+        warnings.warn("--keep-ld-library-path is the default now - this flag might be removed in the future", FutureWarning)
+    kargs["keep_ld_library_path"]=True
     cron.cron(**kargs)
 
 @command("required", help="print requirements",
