@@ -23,13 +23,21 @@ def find_free_port():
         s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         return s.getsockname()[1]
 
+def _adjust_sockname(sockname,port):
+    pwd=os.getcwd()
+    pwd=re.sub("[^-A-Za-z0-9.]",":",pwd)
+    sockname=re.sub(r"\(path\)",pwd,sockname)
+    sockname=re.sub(r"\(port\)",str(port),sockname)
+    return sockname
+
 def run_server(dry_run: bool = False,
                port: int = 0,
                screen_cmd: str = "screen",
+               screen_log: str = "",
                no_screen: bool = False,
-               keep_ld_library_path: bool = False,
+               keep_ld_library_path: bool = True,
                python_exec: str = "",
-               sockname: str = "jupyter-server",
+               sockname: str = "(path):jupyter-server:(port)",
                detach: bool = False):
     """Runs a jupyter server inside a screen command.
 
@@ -42,22 +50,34 @@ def run_server(dry_run: bool = False,
     if port == 0:
         port = find_free_port()
     print("port:", port)
-    cmd = ""
+    cmd = []
     if not no_screen:
-        cmd += screen_cmd
+        cmd.extend(screen_cmd.split()) # allows screen_cmd to contain space separated options
         if detach:
-            cmd += " -d"
-        cmd += " -m -S " + sockname + "-" + str(port) + " "
-    if keep_ld_library_path and 'LD_LIBRARY_PATH' in os.environ:
-        cmd += "env LD_LIBRARY_PATH='"
-        cmd += os.environ["LD_LIBRARY_PATH"]
-        cmd += "' "
-    cmd += python_exec + " -m jupyter notebook --no-browser "
-    cmd += "--port=" + str(port)
+            cmd.append("-d")
+        if screen_log != "":
+            cmd.append("-L")
+            if screen_log != "screenlog.0":
+              cmd.append("-Logfile")
+              cmd.append(screen_log)
+        cmd.append("-m")
+        cmd.append("-h")
+        cmd.append("100000") # scrollback
+        cmd.append("-S")
+        cmd.append(_adjust_sockname(sockname,port))
+        if keep_ld_library_path and 'LD_LIBRARY_PATH' in os.environ:
+            cmd.append("env")
+            cmd.append("LD_LIBRARY_PATH=" + os.environ["LD_LIBRARY_PATH"])
+    cmd.extend(python_exec.split()) # allows python_exec to contain space separated options
+    cmd.append("-m")
+    cmd.append("jupyter")
+    cmd.append("notebook")
+    cmd.append("--no-browser")
+    cmd.append("--port=" + str(port))
     print("cmd:", cmd)
     if dry_run:
         return
-    os.system(cmd)
+    subprocess.call(cmd)
 
 def remote(server: str,
            python_exec: str = "python",
@@ -117,26 +137,30 @@ def remote(server: str,
 
     ssh_cmd = ["ssh", "-NL", str(port) + ":localhost:" + str(server_port), server]
 
+    xopen_cmd = [] # list rather than string
+
     if open_cmd == "":
         plat = platform.system()
         if plat == "Darwin":
-            open_cmd = "open"
+            xopen_cmd.append("open")
         elif plat == "Linux":
-            open_cmd = "xdg-open"
+            xopen_cmd.append("xdg-open")
         else:
             raise Exception("Unknown platform " + plat)
-    print("open_cmd:", open_cmd)
+    else:
+        xopen_cmd = [open_cmd]
 
-    open_cmd = open_cmd + " " + re.sub(":" + str(server_port), ":" + str(port), url)
+    xopen_cmd.append(re.sub(":" + str(server_port), ":" + str(port), url))
+    print("open_cmd:", ' '.join(xopen_cmd))
     print("ssh:", ' '.join(ssh_cmd))
     if dry_run:
-        print(open_cmd)
+        print(xopen_cmd)
     else:
         ssh = subprocess.Popen(ssh_cmd)
         try:
             print("Don't kill this terminal or you will be disconnected!")
             time.sleep(1)
-            os.system(open_cmd)
+            subprocess.call(xopen_cmd)
             print("Use CTRL+c to kill the connection")
         except KeyboardInterrupt:
             print("Interrupted")
